2D Turbulence using multigrid
=============================

This examples demonstrates the use of the multigrid Laplacian inversion solver
for a 2D turbulence based on the physics model implemented in `ESEL`
(Interchange turbulence in the TCV scrape-off layer, Garcia et al, PPCF 2006,
DOI: [10.1088/0741-3335/48/1/L01](https://doi.org/10.1088/0741-3335/48/1/L01))
